!
! $Header$
!
MODULE phys_output_write_mod

    USE phytrac_mod, ONLY : d_tr_cl, d_tr_th, d_tr_cv, d_tr_lessi_impa, &
        d_tr_lessi_nucl, d_tr_insc, d_tr_bcscav, d_tr_evapls, d_tr_ls,  &
        d_tr_trsp, d_tr_sscav, d_tr_sat, d_tr_uscav


! Author: Abderrahmane IDELKADI (original include file)
! Author: Laurent FAIRHEAD (transformation to module/subroutine)
! Author: Ulysse GERARD (effective implementation)


   CONTAINS 
     
! ug Routine pour définir (los du premier passageà) ET sortir les variables
    SUBROUTINE phys_output_write(itap, pdtphys, paprs, pphis, &
   &                  pplay, lmax_th, aerosol_couple,         &
   &                  ok_ade, ok_aie, ivap, new_aod, ok_sync, &
   &                  ptconv, read_climoz, clevSTD, ptconvth, &
   &                  d_t, qx, d_qx, zmasse, flag_aerosol_strat)

! This subroutine does the actual writing of diagnostics that were
! defined and initialised in phys_output_mod.F90

    USE dimphy
    USE control_mod
    USE phys_output_ctrlout_mod 
    USE phys_state_var_mod
    USE phys_local_var_mod
    USE indice_sol_mod
    USE infotrac
    USE comgeomphy
    USE surface_data,     ONLY : type_ocean, ok_veget
    USE aero_mod
    USE ioipsl
    USE write_field_phy
    USE iophy

    IMPLICIT NONE

    INCLUDE "temps.h"
    INCLUDE "clesphys.h"
    INCLUDE "thermcell.h"
    INCLUDE "compbl.h"
    INCLUDE "YOMCST.h"
    INCLUDE "dimensions.h"

! Input
    INTEGER :: itap, ivap, read_climoz
    INTEGER, DIMENSION(klon) :: lmax_th
    LOGICAL :: aerosol_couple, ok_sync
    LOGICAL :: ok_ade, ok_aie, new_aod
    LOGICAL, DIMENSION(klon, klev) :: ptconv, ptconvth
    REAL :: pdtphys
    CHARACTER (LEN=4), DIMENSION(nlevSTD) :: clevSTD
    REAL, DIMENSION(klon) :: pphis
    REAL, DIMENSION(klon, klev) :: pplay, d_t
    REAL, DIMENSION(klon, klev+1) :: paprs
    REAL, DIMENSION(klon,klev,nqtot) :: qx, d_qx
    REAL, DIMENSION(klon, llm) :: zmasse
    LOGICAL :: flag_aerosol_strat

! Local
    INTEGER, PARAMETER :: jjmp1=jjm+1-1/jjm
    INTEGER :: itau_w
    INTEGER :: i, iff, iq, nsrf, k, ll, naero
    REAL, DIMENSION (klon) :: zx_tmp_fi2d
    REAL, DIMENSION (klon,klev) :: zx_tmp_fi3d, zpt_conv
    REAL, DIMENSION (klon,klev+1) :: zx_tmp_fi3d1
    CHARACTER (LEN=4)              :: bb2
    INTEGER, DIMENSION(iim*jjmp1)  :: ndex2d
    INTEGER, DIMENSION(iim*jjmp1*klev) :: ndex3d
    REAL, PARAMETER :: dobson_u = 2.1415e-05 ! Dobson unit, in kg m-2

    IF(vars_defined) THEN
! On calcul le nouveau tau:
     itau_w = itau_phy + itap + start_time * day_step / iphysiq
! On le donne à iophy pour que les histwrite y aient accès:
     CALL set_itau_iophy(itau_w)
    ENDIF

! On procède à l'écriture ou à la définition des nombreuses variables:
!!! Champs 1D !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      CALL histwrite_phy(o_phis, pphis)
      CALL histwrite_phy(o_aire, airephy)

IF (itap > 0) THEN
      DO i=1, klon
       zx_tmp_fi2d(i)=pctsrf(i,is_ter)+pctsrf(i,is_lic)
      ENDDO
ENDIF

      CALL histwrite_phy(o_contfracATM, zx_tmp_fi2d)
      CALL histwrite_phy(o_contfracOR, pctsrf(:,is_ter))
      CALL histwrite_phy(o_aireTER, paire_ter)
!!! Champs 2D !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      CALL histwrite_phy(o_flat, zxfluxlat)
      CALL histwrite_phy(o_slp, slp)
      CALL histwrite_phy(o_tsol, zxtsol)
      CALL histwrite_phy(o_t2m, zt2m)
      CALL histwrite_phy(o_t2m_min, zt2m)
      CALL histwrite_phy(o_t2m_max, zt2m)

IF (itap > 0) THEN
      DO i=1, klon
       zx_tmp_fi2d(i)=SQRT(zu10m(i)*zu10m(i)+zv10m(i)*zv10m(i))
      ENDDO
ENDIF
      CALL histwrite_phy(o_wind10m, zx_tmp_fi2d)

IF (itap > 0) THEN
      DO i=1, klon
       zx_tmp_fi2d(i)=SQRT(zu10m(i)*zu10m(i)+zv10m(i)*zv10m(i))
      ENDDO
ENDIF
      CALL histwrite_phy(o_wind10max, zx_tmp_fi2d)

IF (itap > 0) THEN
      DO i = 1, klon
         zx_tmp_fi2d(i) = pctsrf(i,is_sic)
      ENDDO
ENDIF
      CALL histwrite_phy(o_sicf, zx_tmp_fi2d)
      CALL histwrite_phy(o_q2m, zq2m)
      CALL histwrite_phy(o_ustar, zustar)
      CALL histwrite_phy(o_u10m, zu10m)
      CALL histwrite_phy(o_v10m, zv10m)

IF (itap > 0) THEN
      DO i = 1, klon
         zx_tmp_fi2d(i) = paprs(i,1)
      ENDDO
ENDIF
      CALL histwrite_phy(o_psol, zx_tmp_fi2d)
      CALL histwrite_phy(o_mass, zmasse)
      CALL histwrite_phy(o_qsurf, zxqsurf)

IF (.NOT. ok_veget) THEN
      CALL histwrite_phy(o_qsol, qsol)
ENDIF

IF (itap > 0) THEN
       DO i = 1, klon
         zx_tmp_fi2d(i) = rain_fall(i) + snow_fall(i)
       ENDDO
ENDIF

      CALL histwrite_phy(o_precip, zx_tmp_fi2d)
      CALL histwrite_phy(o_ndayrain, nday_rain)

IF (itap > 0) THEN
       DO i = 1, klon
         zx_tmp_fi2d(i) = rain_lsc(i) + snow_lsc(i)
       ENDDO
ENDIF
      CALL histwrite_phy(o_plul, zx_tmp_fi2d)

IF (itap > 0) THEN
      DO i = 1, klon
         zx_tmp_fi2d(i) = rain_con(i) + snow_con(i)
      ENDDO
ENDIF
      CALL histwrite_phy(o_pluc, zx_tmp_fi2d)
      CALL histwrite_phy(o_snow, snow_fall)
      CALL histwrite_phy(o_msnow, snow_o)
      CALL histwrite_phy(o_fsnow, zfra_o)
      CALL histwrite_phy(o_evap, evap)
      CALL histwrite_phy(o_tops, topsw)
      CALL histwrite_phy(o_tops0, topsw0)
      CALL histwrite_phy(o_topl, toplw)
      CALL histwrite_phy(o_topl0, toplw0)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swup ( 1 : klon, klevp1 )
ENDIF
      CALL histwrite_phy(o_SWupTOA, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swup0 ( 1 : klon, klevp1 )
ENDIF
      CALL histwrite_phy(o_SWupTOAclr, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swdn ( 1 : klon, klevp1 )
ENDIF
      CALL histwrite_phy(o_SWdnTOA, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swdn0 ( 1 : klon, klevp1 )
ENDIF
      CALL histwrite_phy(o_SWdnTOAclr, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(:) = topsw(:)-toplw(:)
ENDIF
      CALL histwrite_phy(o_nettop, zx_tmp_fi2d)
      CALL histwrite_phy(o_SWup200, SWup200)
      CALL histwrite_phy(o_SWup200clr, SWup200clr)
      CALL histwrite_phy(o_SWdn200, SWdn200)
      CALL histwrite_phy(o_SWdn200clr, SWdn200clr)
      CALL histwrite_phy(o_LWup200, LWup200)
      CALL histwrite_phy(o_LWup200clr, LWup200clr)
      CALL histwrite_phy(o_LWdn200, LWdn200)
      CALL histwrite_phy(o_LWdn200clr, LWdn200clr)
      CALL histwrite_phy(o_sols, solsw)
      CALL histwrite_phy(o_sols0, solsw0)
      CALL histwrite_phy(o_soll, sollw)
      CALL histwrite_phy(o_radsol, radsol)
      CALL histwrite_phy(o_soll0, sollw0)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swup ( 1 : klon, 1 )
ENDIF
      CALL histwrite_phy(o_SWupSFC, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swup0 ( 1 : klon, 1 )
ENDIF
      CALL histwrite_phy(o_SWupSFCclr, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swdn ( 1 : klon, 1 )
ENDIF
      CALL histwrite_phy(o_SWdnSFC, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1 : klon) = swdn0 ( 1 : klon, 1 )
ENDIF
      CALL histwrite_phy(o_SWdnSFCclr, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d(1:klon)=sollwdown(1:klon)-sollw(1:klon)
ENDIF
      CALL histwrite_phy(o_LWupSFC, zx_tmp_fi2d)
      CALL histwrite_phy(o_LWdnSFC, sollwdown)

IF (itap > 0) THEN
       sollwdownclr(1:klon) = -1.*lwdn0(1:klon,1)
      zx_tmp_fi2d(1:klon)=sollwdownclr(1:klon)-sollw0(1:klon)
ENDIF
      CALL histwrite_phy(o_LWupSFCclr, zx_tmp_fi2d)
      CALL histwrite_phy(o_LWdnSFCclr, sollwdownclr)
      CALL histwrite_phy(o_bils, bils)
      CALL histwrite_phy(o_bils_diss, bils_diss)
      CALL histwrite_phy(o_bils_ec, bils_ec)
      CALL histwrite_phy(o_bils_tke, bils_tke)
      CALL histwrite_phy(o_bils_kinetic, bils_kinetic)
      CALL histwrite_phy(o_bils_latent, bils_latent)
      CALL histwrite_phy(o_bils_enthalp, bils_enthalp)

IF (itap > 0) THEN
      zx_tmp_fi2d(1:klon)=-1*sens(1:klon)
ENDIF
      CALL histwrite_phy(o_sens, zx_tmp_fi2d)
      CALL histwrite_phy(o_fder, fder)
      CALL histwrite_phy(o_ffonte, zxffonte)
      CALL histwrite_phy(o_fqcalving, zxfqcalving)
      CALL histwrite_phy(o_fqfonte, zxfqfonte)
IF (itap > 0) THEN
      zx_tmp_fi2d=0.
      DO nsrf=1,nbsrf
        zx_tmp_fi2d(:)=zx_tmp_fi2d(:)+pctsrf(:,nsrf)*fluxu(:,1,nsrf)
      ENDDO
ENDIF
      CALL histwrite_phy(o_taux, zx_tmp_fi2d)

IF (itap > 0) THEN
      zx_tmp_fi2d=0.
      DO nsrf=1,nbsrf
          zx_tmp_fi2d(:)=zx_tmp_fi2d(:)+pctsrf(:,nsrf)*fluxv(:,1,nsrf)
      ENDDO
ENDIF
      CALL histwrite_phy(o_tauy, zx_tmp_fi2d)


         DO nsrf = 1, nbsrf
IF (itap > 0)             zx_tmp_fi2d(1 : klon) = pctsrf( 1 : klon, nsrf)*100.
      CALL histwrite_phy(o_pourc_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)           zx_tmp_fi2d(1 : klon) = pctsrf( 1 : klon, nsrf)
      CALL histwrite_phy(o_fract_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = fluxu( 1 : klon, 1, nsrf)
      CALL histwrite_phy(o_taux_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = fluxv( 1 : klon, 1, nsrf)
      CALL histwrite_phy(o_tauy_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = ftsol( 1 : klon, nsrf)
      CALL histwrite_phy(o_tsol_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = evap_pot( 1 : klon, nsrf)
      CALL histwrite_phy(o_evappot_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)       zx_tmp_fi2d(1 : klon) = ustar(1 : klon, nsrf)
      CALL histwrite_phy(o_ustar_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)       zx_tmp_fi2d(1 : klon) = u10m(1 : klon, nsrf)
      CALL histwrite_phy(o_u10m_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)       zx_tmp_fi2d(1 : klon) = v10m(1 : klon, nsrf)
      CALL histwrite_phy(o_v10m_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)       zx_tmp_fi2d(1 : klon) = t2m(1 : klon, nsrf)
      CALL histwrite_phy(o_t2m_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)       zx_tmp_fi2d(1 : klon) = fevap(1 : klon, nsrf)
      CALL histwrite_phy(o_evap_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)        zx_tmp_fi2d(1 : klon) = fluxt( 1 : klon, 1, nsrf)
      CALL histwrite_phy(o_sens_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = fluxlat( 1 : klon, nsrf)
      CALL histwrite_phy(o_lat_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = fsollw( 1 : klon, nsrf)
      CALL histwrite_phy(o_flw_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = fsolsw( 1 : klon, nsrf)
      CALL histwrite_phy(o_fsw_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = wfbils( 1 : klon, nsrf)
      CALL histwrite_phy(o_wbils_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0)         zx_tmp_fi2d(1 : klon) = wfbilo( 1 : klon, nsrf)
      CALL histwrite_phy(o_wbilo_srf(nsrf), zx_tmp_fi2d)

      IF (iflag_pbl > 1) THEN
      CALL histwrite_phy(o_tke_srf(nsrf),  pbl_tke(:,1:klev,nsrf))
      CALL histwrite_phy(o_tke_max_srf(nsrf),  pbl_tke(:,1:klev,nsrf))
      ENDIF

      ENDDO
      CALL histwrite_phy(o_cdrm, cdragm)
      CALL histwrite_phy(o_cdrh, cdragh)
      CALL histwrite_phy(o_cldl, cldl)
      CALL histwrite_phy(o_cldm, cldm)
      CALL histwrite_phy(o_cldh, cldh)
      CALL histwrite_phy(o_cldt, cldt)
      CALL histwrite_phy(o_cldq, cldq)
IF (itap > 0)       zx_tmp_fi2d(1:klon) = flwp(1:klon)
      CALL histwrite_phy(o_lwp, zx_tmp_fi2d)
IF (itap > 0)       zx_tmp_fi2d(1:klon) = fiwp(1:klon)
      CALL histwrite_phy(o_iwp, zx_tmp_fi2d)
      CALL histwrite_phy(o_ue, ue)
      CALL histwrite_phy(o_ve, ve)
      CALL histwrite_phy(o_uq, uq)
      CALL histwrite_phy(o_vq, vq)
      IF(iflag_con.GE.3) THEN ! sb
      CALL histwrite_phy(o_cape, cape)
      CALL histwrite_phy(o_pbase, ema_pcb)
      CALL histwrite_phy(o_ptop, ema_pct)
      CALL histwrite_phy(o_fbase, ema_cbmf)
        if (iflag_con /= 30) then
      CALL histwrite_phy(o_plcl, plcl)
      CALL histwrite_phy(o_plfc, plfc)
      CALL histwrite_phy(o_wbeff, wbeff)
        end if

      CALL histwrite_phy(o_cape_max, cape)

      CALL histwrite_phy(o_upwd, upwd)
      CALL histwrite_phy(o_Ma, Ma)
      CALL histwrite_phy(o_dnwd, dnwd)
      CALL histwrite_phy(o_dnwd0, dnwd0)
IF (itap > 0)         zx_tmp_fi2d=float(itau_con)/float(itap)
      CALL histwrite_phy(o_ftime_con, zx_tmp_fi2d)
IF (itap > 0) THEN
      IF(iflag_thermals>=1)THEN
         zx_tmp_fi3d=dnwd+dnwd0+upwd+fm_therm(:,1:klev)
      ELSE
         zx_tmp_fi3d=dnwd+dnwd0+upwd
      ENDIF
ENDIF
      CALL histwrite_phy(o_mc, zx_tmp_fi3d)
      ENDIF !iflag_con .GE. 3
      CALL histwrite_phy(o_prw, prw)
      CALL histwrite_phy(o_s_pblh, s_pblh)
      CALL histwrite_phy(o_s_pblt, s_pblt)
      CALL histwrite_phy(o_s_lcl, s_lcl)
      CALL histwrite_phy(o_s_therm, s_therm)
!IM : Les champs suivants (s_capCL, s_oliqCL, s_cteiCL, s_trmb1, s_trmb2, s_trmb3) ne sont pas definis dans HBTM.F
!       IF (o_s_capCL%flag(iff)<=lev_files(iff)) THEN
!     CALL histwrite_phy(nid_files(iff),clef_stations(iff),
!    $o_s_capCL%name,itau_w,s_capCL)
!       ENDIF
!       IF (o_s_oliqCL%flag(iff)<=lev_files(iff)) THEN
!     CALL histwrite_phy(nid_files(iff),clef_stations(iff),
!    $o_s_oliqCL%name,itau_w,s_oliqCL)
!       ENDIF
!       IF (o_s_cteiCL%flag(iff)<=lev_files(iff)) THEN
!     CALL histwrite_phy(nid_files(iff),clef_stations(iff),
!    $o_s_cteiCL%name,itau_w,s_cteiCL)
!       ENDIF
!       IF (o_s_trmb1%flag(iff)<=lev_files(iff)) THEN
!     CALL histwrite_phy(nid_files(iff),clef_stations(iff),
!    $o_s_trmb1%name,itau_w,s_trmb1)
!       ENDIF
!       IF (o_s_trmb2%flag(iff)<=lev_files(iff)) THEN
!     CALL histwrite_phy(nid_files(iff),clef_stations(iff),
!    $o_s_trmb2%name,itau_w,s_trmb2)
!       ENDIF
!       IF (o_s_trmb3%flag(iff)<=lev_files(iff)) THEN
!     CALL histwrite_phy(nid_files(iff),clef_stations(iff),
!    $o_s_trmb3%name,itau_w,s_trmb3)
!       ENDIF



! ATTENTION, LES ANCIENS HISTWRITE ONT ETES CONSERVES EN ATTENDANT MIEUX:
! Champs interpolles sur des niveaux de pression
      DO iff=1, nfiles
        ll=0
        DO k=1, nlevSTD
         bb2=clevSTD(k) 
         IF(bb2.EQ."850".OR.bb2.EQ."700".OR. &
            bb2.EQ."500".OR.bb2.EQ."200".OR. &
            bb2.EQ."100".OR. &
            bb2.EQ."50".OR.bb2.EQ."10") THEN

! a refaire correctement !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          ll=ll+1
      CALL histwrite_phy(o_uSTDlevs(ll),uwriteSTD(:,k,iff), iff)
      CALL histwrite_phy(o_vSTDlevs(ll),vwriteSTD(:,k,iff), iff)
      CALL histwrite_phy(o_wSTDlevs(ll),wwriteSTD(:,k,iff), iff)
      CALL histwrite_phy(o_zSTDlevs(ll),phiwriteSTD(:,k,iff), iff)
      CALL histwrite_phy(o_qSTDlevs(ll),qwriteSTD(:,k,iff), iff)
      CALL histwrite_phy(o_tSTDlevs(ll),twriteSTD(:,k,iff), iff)

       ENDIF !(bb2.EQ."850".OR.bb2.EQ."700".OR.
       ENDDO
       ENDDO



IF (itap > 0) THEN
      DO i=1, klon
       IF (pctsrf(i,is_oce).GT.epsfra.OR. &
           pctsrf(i,is_sic).GT.epsfra) THEN
        zx_tmp_fi2d(i) = (ftsol(i, is_oce) * pctsrf(i,is_oce)+ &
                         ftsol(i, is_sic) * pctsrf(i,is_sic))/ &
                         (pctsrf(i,is_oce)+pctsrf(i,is_sic))
       ELSE
        zx_tmp_fi2d(i) = 273.15
       ENDIF
      ENDDO
ENDIF
      CALL histwrite_phy(o_t_oce_sic, zx_tmp_fi2d)

! Couplage convection-couche limite
      IF (iflag_con.GE.3) THEN
      IF (iflag_coupl>=1) THEN
      CALL histwrite_phy(o_ale_bl, ale_bl)
      CALL histwrite_phy(o_alp_bl, alp_bl)
      ENDIF !iflag_coupl>=1
      ENDIF !(iflag_con.GE.3)
! Wakes
      IF (iflag_con.EQ.3) THEN
      IF (iflag_wake>=1) THEN
      CALL histwrite_phy(o_ale_wk, ale_wake)
      CALL histwrite_phy(o_alp_wk, alp_wake)
      CALL histwrite_phy(o_ale, ale)
      CALL histwrite_phy(o_alp, alp)
      CALL histwrite_phy(o_cin, cin)
      CALL histwrite_phy(o_WAPE, wake_pe)
      CALL histwrite_phy(o_wake_h, wake_h)
      CALL histwrite_phy(o_wake_s, wake_s)
      CALL histwrite_phy(o_wake_deltat, wake_deltat)
      CALL histwrite_phy(o_wake_deltaq, wake_deltaq)
      CALL histwrite_phy(o_wake_omg, wake_omg)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_wake(1:klon,1:klev) &
                                              /pdtphys
      CALL histwrite_phy(o_dtwak, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_wake(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqwak, zx_tmp_fi3d)
      ENDIF ! iflag_wake>=1
      CALL histwrite_phy(o_Vprecip, Vprecip)
      CALL histwrite_phy(o_ftd, ftd)
      CALL histwrite_phy(o_fqd, fqd)
      ELSEIF (iflag_con.EQ.30) THEN
! sortie RomP convection descente insaturee iflag_con=30
      CALL histwrite_phy(o_Vprecip, Vprecip)
      CALL histwrite_phy(o_wdtrainA, wdtrainA)
      CALL histwrite_phy(o_wdtrainM, wdtrainM)
      ENDIF !(iflag_con.EQ.3.or.iflag_con.EQ.30)
!!! nrlmd le 10/04/2012
        IF (iflag_trig_bl>=1) THEN
      CALL histwrite_phy(o_n2, n2)
      CALL histwrite_phy(o_s2, s2)
      CALL histwrite_phy(o_proba_notrig, proba_notrig)
      CALL histwrite_phy(o_random_notrig, random_notrig)
      CALL histwrite_phy(o_ale_bl_stat, ale_bl_stat)
      CALL histwrite_phy(o_ale_bl_trig, ale_bl_trig)
       ENDIF  !(iflag_trig_bl>=1)
        IF (iflag_clos_bl>=1) THEN
      CALL histwrite_phy(o_alp_bl_det, alp_bl_det)
      CALL histwrite_phy(o_alp_bl_fluct_m, alp_bl_fluct_m)
      CALL histwrite_phy(o_alp_bl_fluct_tke,  &
       alp_bl_fluct_tke)
      CALL histwrite_phy(o_alp_bl_conv, alp_bl_conv)
      CALL histwrite_phy(o_alp_bl_stat, alp_bl_stat)
       ENDIF  !(iflag_clos_bl>=1)
!!! fin nrlmd le 10/04/2012
      IF (type_ocean=='slab ') THEN
      CALL histwrite_phy(o_slab_bils, slab_wfbils)
      ENDIF !type_ocean == force/slab
      CALL histwrite_phy(o_weakinv, weak_inversion)
      CALL histwrite_phy(o_dthmin, dthmin)
      CALL histwrite_phy(o_cldtau, cldtau)
      CALL histwrite_phy(o_cldemi, cldemi)
      CALL histwrite_phy(o_pr_con_l, pmflxr(:,1:klev))
      CALL histwrite_phy(o_pr_con_i, pmflxs(:,1:klev))
      CALL histwrite_phy(o_pr_lsc_l, prfl(:,1:klev))
      CALL histwrite_phy(o_pr_lsc_i, psfl(:,1:klev))
      CALL histwrite_phy(o_re, re)
      CALL histwrite_phy(o_fl, fl)
IF (itap > 0) THEN
      DO i=1, klon
       zx_tmp_fi2d(i)=MIN(100.,rh2m(i)*100.)
      ENDDO
ENDIF
      CALL histwrite_phy(o_rh2m, zx_tmp_fi2d)

IF (itap > 0) THEN
      DO i=1, klon
       zx_tmp_fi2d(i)=MIN(100.,rh2m(i)*100.)
      ENDDO
ENDIF
      CALL histwrite_phy(o_rh2m_min, zx_tmp_fi2d)

IF (itap > 0) THEN
      DO i=1, klon
       zx_tmp_fi2d(i)=MIN(100.,rh2m(i)*100.)
      ENDDO
ENDIF
      CALL histwrite_phy(o_rh2m_max, zx_tmp_fi2d)

      CALL histwrite_phy(o_qsat2m, qsat2m)
      CALL histwrite_phy(o_tpot, tpot)
      CALL histwrite_phy(o_tpote, tpote)
IF (itap > 0) zx_tmp_fi2d(1 : klon) = fsolsw( 1 : klon, is_ter)
      CALL histwrite_phy(o_SWnetOR,  zx_tmp_fi2d)
IF (itap > 0) zx_tmp_fi2d(1:klon) = solsw(1:klon)/(1.-albsol1(1:klon))
      CALL histwrite_phy(o_SWdownOR,  zx_tmp_fi2d)
      CALL histwrite_phy(o_LWdownOR, sollwdown)
      CALL histwrite_phy(o_snowl, snow_lsc)
      CALL histwrite_phy(o_solldown, sollwdown)
      CALL histwrite_phy(o_dtsvdfo, d_ts(:,is_oce))
      CALL histwrite_phy(o_dtsvdft, d_ts(:,is_ter))
      CALL histwrite_phy(o_dtsvdfg,  d_ts(:,is_lic))
      CALL histwrite_phy(o_dtsvdfi, d_ts(:,is_sic))
      CALL histwrite_phy(o_rugs, zxrugs)
! OD550 per species
      IF (new_aod .and. (.not. aerosol_couple)) THEN
          IF (ok_ade.OR.ok_aie) THEN
      CALL histwrite_phy(o_od550aer, od550aer)
      CALL histwrite_phy(o_od865aer, od865aer)
      CALL histwrite_phy(o_absvisaer, absvisaer)
      CALL histwrite_phy(o_od550lt1aer, od550lt1aer)
      CALL histwrite_phy(o_sconcso4, sconcso4)
      CALL histwrite_phy(o_sconcoa, sconcoa)
      CALL histwrite_phy(o_sconcbc, sconcbc)
      CALL histwrite_phy(o_sconcss, sconcss)
      CALL histwrite_phy(o_sconcdust, sconcdust)
      CALL histwrite_phy(o_concso4, concso4)
      CALL histwrite_phy(o_concoa, concoa)
      CALL histwrite_phy(o_concbc, concbc)
      CALL histwrite_phy(o_concss, concss)
      CALL histwrite_phy(o_concdust, concdust)
      CALL histwrite_phy(o_loadso4, loadso4)
      CALL histwrite_phy(o_loadoa, loadoa)
      CALL histwrite_phy(o_loadbc, loadbc)
      CALL histwrite_phy(o_loadss, loadss)
      CALL histwrite_phy(o_loaddust, loaddust)
!--STRAT AER
          ENDIF
          IF (ok_ade.OR.ok_aie.OR.flag_aerosol_strat) THEN
          DO naero = 1, naero_spc
      CALL histwrite_phy(o_tausumaero(naero), &
       tausum_aero(:,2,naero) )
          END DO
          ENDIF
      ENDIF
       IF (ok_ade) THEN
      CALL histwrite_phy(o_topswad, topswad_aero)
      CALL histwrite_phy(o_topswad0, topswad0_aero)
      CALL histwrite_phy(o_solswad, solswad_aero)
      CALL histwrite_phy(o_solswad0, solswad0_aero)
!====MS forcing diagnostics
        if (new_aod) then
      CALL histwrite_phy(o_swtoaas_nat, topsw_aero(:,1))
      CALL histwrite_phy(o_swsrfas_nat, solsw_aero(:,1))
      CALL histwrite_phy(o_swtoacs_nat, topsw0_aero(:,1))
      CALL histwrite_phy(o_swsrfcs_nat, solsw0_aero(:,1))
!ant
      CALL histwrite_phy(o_swtoaas_ant, topsw_aero(:,2))
      CALL histwrite_phy(o_swsrfas_ant, solsw_aero(:,2))
      CALL histwrite_phy(o_swtoacs_ant, topsw0_aero(:,2))
      CALL histwrite_phy(o_swsrfcs_ant, solsw0_aero(:,2))
!cf
        if (.not. aerosol_couple) then
      CALL histwrite_phy(o_swtoacf_nat, topswcf_aero(:,1))
      CALL histwrite_phy(o_swsrfcf_nat, solswcf_aero(:,1))
      CALL histwrite_phy(o_swtoacf_ant, topswcf_aero(:,2))
      CALL histwrite_phy(o_swsrfcf_ant, solswcf_aero(:,2))
      CALL histwrite_phy(o_swtoacf_zero,topswcf_aero(:,3))
      CALL histwrite_phy(o_swsrfcf_zero,solswcf_aero(:,3))
        endif
    endif ! new_aod
!====MS forcing diagnostics
       ENDIF
       IF (ok_aie) THEN
      CALL histwrite_phy(o_topswai, topswai_aero)
      CALL histwrite_phy(o_solswai, solswai_aero)
      CALL histwrite_phy(o_scdnc, scdnc)
      CALL histwrite_phy(o_cldncl, cldncl)
      CALL histwrite_phy(o_reffclws, reffclws)
      CALL histwrite_phy(o_reffclwc, reffclwc)
      CALL histwrite_phy(o_cldnvi, cldnvi)
      CALL histwrite_phy(o_lcc, lcc)
      CALL histwrite_phy(o_lcc3d, lcc3d)
      CALL histwrite_phy(o_lcc3dcon, lcc3dcon)
      CALL histwrite_phy(o_lcc3dstra, lcc3dstra)
      CALL histwrite_phy(o_reffclwtop, reffclwtop)
       ENDIF
! Champs 3D:
       IF (ok_ade .OR. ok_aie) then
      CALL histwrite_phy(o_ec550aer, ec550aer)
       ENDIF
      CALL histwrite_phy(o_lwcon, flwc)
      CALL histwrite_phy(o_iwcon, fiwc)
      CALL histwrite_phy(o_temp, t_seri)
      CALL histwrite_phy(o_theta, theta)
      CALL histwrite_phy(o_ovapinit, qx(:,:,ivap))
      CALL histwrite_phy(o_ovap, q_seri)
      CALL histwrite_phy(o_oliq, ql_seri)
      CALL histwrite_phy(o_geop, zphi)
      CALL histwrite_phy(o_vitu, u_seri)
      CALL histwrite_phy(o_vitv, v_seri)
      CALL histwrite_phy(o_vitw, omega)
      CALL histwrite_phy(o_pres, pplay)
      CALL histwrite_phy(o_paprs, paprs(:,1:klev))
IF (itap > 0) THEN
         DO i=1, klon
          zx_tmp_fi3d1(i,1)= pphis(i)/RG
!020611   zx_tmp_fi3d(i,1)= pphis(i)/RG
         ENDDO
         DO k=1, klev
!020611        DO k=1, klev-1
         DO i=1, klon
!020611         zx_tmp_fi3d(i,k+1)= zx_tmp_fi3d(i,k) - (t_seri(i,k) *RD * 
          zx_tmp_fi3d1(i,k+1)= zx_tmp_fi3d1(i,k) - (t_seri(i,k) *RD *  &
          (paprs(i,k+1) - paprs(i,k))) / ( pplay(i,k) * RG ) 
         ENDDO
         ENDDO
ENDIF
      CALL histwrite_phy(o_zfull,zx_tmp_fi3d1(:,2:klevp1))
!020611    $o_zfull%name,itau_w,zx_tmp_fi3d)

IF (itap > 0)  THEN
         DO i=1, klon
          zx_tmp_fi3d(i,1)= pphis(i)/RG - ( &
          (t_seri(i,1)+zxtsol(i))/2. *RD * &
          (pplay(i,1) - paprs(i,1)))/( (paprs(i,1)+pplay(i,1))/2.* RG)
         ENDDO
         DO k=1, klev-1
         DO i=1, klon
          zx_tmp_fi3d(i,k+1)= zx_tmp_fi3d(i,k) - ( &
          (t_seri(i,k)+t_seri(i,k+1))/2. *RD *  &
          (pplay(i,k+1) - pplay(i,k))) / ( paprs(i,k) * RG ) 
         ENDDO
         ENDDO
ENDIF
      CALL histwrite_phy(o_zhalf, zx_tmp_fi3d)
      CALL histwrite_phy(o_rneb, cldfra)
      CALL histwrite_phy(o_rnebcon, rnebcon)
      CALL histwrite_phy(o_rnebls, rneb)
      CALL histwrite_phy(o_rhum, zx_rh)
      CALL histwrite_phy(o_ozone, &
       wo(:, :, 1) * dobson_u * 1e3 / zmasse / rmo3 * rmd)

      IF (read_climoz == 2) THEN
      CALL histwrite_phy(o_ozone_light, &
       wo(:, :, 2) * dobson_u * 1e3 / zmasse / rmo3 * rmd)
      ENDIF

      CALL histwrite_phy(o_dtphy, d_t)
      CALL histwrite_phy(o_dqphy,  d_qx(:,:,ivap))
        DO nsrf=1, nbsrf
IF (itap > 0) zx_tmp_fi2d(1 : klon) = falb1( 1 : klon, nsrf)
      CALL histwrite_phy(o_albe_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0) zx_tmp_fi2d(1 : klon) = frugs( 1 : klon, nsrf)
      CALL histwrite_phy(o_rugs_srf(nsrf), zx_tmp_fi2d)
IF (itap > 0) zx_tmp_fi2d(1 : klon) = agesno( 1 : klon, nsrf)
      CALL histwrite_phy(o_ages_srf(nsrf), zx_tmp_fi2d)
        ENDDO !nsrf=1, nbsrf
      CALL histwrite_phy(o_alb1, albsol1)
      CALL histwrite_phy(o_alb2, albsol2)
!FH Sorties pour la couche limite
      if (iflag_pbl>1) then
      zx_tmp_fi3d=0.
IF (itap > 0) THEN
      do nsrf=1,nbsrf
         do k=1,klev
          zx_tmp_fi3d(:,k)=zx_tmp_fi3d(:,k) &
          +pctsrf(:,nsrf)*pbl_tke(:,k,nsrf)
         enddo
      enddo
ENDIF
      CALL histwrite_phy(o_tke, zx_tmp_fi3d)

      CALL histwrite_phy(o_tke_max, zx_tmp_fi3d)
      ENDIF

      CALL histwrite_phy(o_kz, coefh(:,:,is_ave))

      CALL histwrite_phy(o_kz_max, coefh(:,:,is_ave))

      CALL histwrite_phy(o_clwcon, clwcon0)
      CALL histwrite_phy(o_dtdyn, d_t_dyn)
      CALL histwrite_phy(o_dqdyn, d_q_dyn)
      CALL histwrite_phy(o_dudyn, d_u_dyn)
      CALL histwrite_phy(o_dvdyn, d_v_dyn)

IF (itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_t_con(1:klon,1:klev)/pdtphys
ENDIF
      CALL histwrite_phy(o_dtcon, zx_tmp_fi3d)
      if(iflag_thermals.eq.1)then
IF (itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_t_con(1:klon,1:klev)/pdtphys + &
                                 d_t_ajsb(1:klon,1:klev)/pdtphys
ENDIF
      CALL histwrite_phy(o_tntc, zx_tmp_fi3d)
      else if(iflag_thermals.gt.1.and.iflag_wake.EQ.1)then
IF (itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_t_con(1:klon,1:klev)/pdtphys + &
                                 d_t_ajs(1:klon,1:klev)/pdtphys + &
                                 d_t_wake(1:klon,1:klev)/pdtphys
ENDIF
      CALL histwrite_phy(o_tntc, zx_tmp_fi3d)
      endif
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_u_con(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_ducon, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_v_con(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dvcon, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_con(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqcon, zx_tmp_fi3d)

      IF(iflag_thermals.EQ.1) THEN
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_con(1:klon,1:klev)/pdtphys
        CALL histwrite_phy(o_tnhusc, zx_tmp_fi3d)
      ELSE IF(iflag_thermals.GT.1.AND.iflag_wake.EQ.1) THEN
IF (itap > 0) THEN
         zx_tmp_fi3d(1:klon,1:klev)=d_q_con(1:klon,1:klev)/pdtphys + &
                                     d_q_ajs(1:klon,1:klev)/pdtphys + &
                                     d_q_wake(1:klon,1:klev)/pdtphys
ENDIF
         CALL histwrite_phy(o_tnhusc, zx_tmp_fi3d)
      ENDIF

IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_lsc(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtlsc, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon, 1:klev)=(d_t_lsc(1:klon,1:klev)+ &
                                 d_t_eva(1:klon,1:klev))/pdtphys
      CALL histwrite_phy(o_dtlschr, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_lsc(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqlsc, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=beta_prec(1:klon,1:klev)
      CALL histwrite_phy(o_beta_prec, zx_tmp_fi3d)
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Sorties specifiques a la separation thermiques/non thermiques
       if (iflag_thermals>=1) then
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_lscth(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtlscth, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_lscst(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtlscst, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_lscth(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqlscth, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_lscst(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqlscst, zx_tmp_fi3d)
      CALL histwrite_phy(o_plulth, plul_th)
      CALL histwrite_phy(o_plulst, plul_st)
IF (itap > 0) THEN
      do k=1,klev
      do i=1,klon
          if (ptconvth(i,k)) then
           zx_tmp_fi3d(i,k)=1.
          else
           zx_tmp_fi3d(i,k)=0.
          endif
      enddo
      enddo
ENDIF
      CALL histwrite_phy(o_ptconvth, zx_tmp_fi3d)
IF (itap > 0) THEN
      do i=1,klon
           zx_tmp_fi2d(1:klon)=lmax_th(:)
      enddo
ENDIF
      CALL histwrite_phy(o_lmaxth, zx_tmp_fi2d)
      endif ! iflag_thermals>=1
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_vdf(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtvdf, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_diss(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtdis, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_vdf(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqvdf, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_eva(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dteva, zx_tmp_fi3d)
IF (itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_eva(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqeva, zx_tmp_fi3d)
      zpt_conv = 0.
      WHERE (ptconv) zpt_conv = 1.
      CALL histwrite_phy(o_ptconv, zpt_conv)
      CALL histwrite_phy(o_ratqs, ratqs)
IF (itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_t_ajs(1:klon,1:klev)/pdtphys - &
                                 d_t_ajsb(1:klon,1:klev)/pdtphys
ENDIF
      CALL histwrite_phy(o_dtthe, zx_tmp_fi3d)
       IF (iflag_thermals>=1) THEN
! Pour l instant 0 a y reflichir pour les thermiques
         zx_tmp_fi2d=0. 
      CALL histwrite_phy(o_ftime_th, zx_tmp_fi2d)
      CALL histwrite_phy(o_f_th, fm_therm)
      CALL histwrite_phy(o_e_th, entr_therm)
      CALL histwrite_phy(o_w_th, zw2)
      CALL histwrite_phy(o_q_th, zqasc)
      CALL histwrite_phy(o_a_th, fraca)
      CALL histwrite_phy(o_d_th, detr_therm)
      CALL histwrite_phy(o_f0_th, f0)
      CALL histwrite_phy(o_zmax_th, zmax_th)
IF (itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_q_ajs(1:klon,1:klev)/pdtphys - &
                                 d_q_ajsb(1:klon,1:klev)/pdtphys
ENDIF
      CALL histwrite_phy(o_dqthe, zx_tmp_fi3d)
      ENDIF !iflag_thermals
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_ajsb(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtajs, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_q_ajsb(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dqajs, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=heat(1:klon,1:klev)/RDAY
      CALL histwrite_phy(o_dtswr, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=heat0(1:klon,1:klev)/RDAY
      CALL histwrite_phy(o_dtsw0, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=-1.*cool(1:klon,1:klev)/RDAY
      CALL histwrite_phy(o_dtlwr, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=-1.*cool0(1:klon,1:klev)/RDAY
      CALL histwrite_phy(o_dtlw0, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_ec(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtec, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_u_vdf(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_duvdf, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_v_vdf(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dvvdf, zx_tmp_fi3d)
       IF (ok_orodr) THEN
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_u_oro(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_duoro, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_v_oro(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dvoro, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_oro(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtoro, zx_tmp_fi3d)
       ENDIF
        IF (ok_orolf) THEN
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_u_lif(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dulif, zx_tmp_fi3d)
       ENDIF
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_v_lif(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dvlif, zx_tmp_fi3d)

IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_lif(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dtlif, zx_tmp_fi3d)

       IF (ok_hines) THEN
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_u_hin(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_duhin, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_v_hin(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dvhin, zx_tmp_fi3d)
IF(itap > 0) zx_tmp_fi3d(1:klon,1:klev)=d_t_hin(1:klon,1:klev)/pdtphys
      CALL histwrite_phy(o_dthin, zx_tmp_fi3d)
        ENDIF
      CALL histwrite_phy(o_rsu, swup)
      CALL histwrite_phy(o_rsd, swdn)
      CALL histwrite_phy(o_rlu, lwup)
      CALL histwrite_phy(o_rld, lwdn)
      CALL histwrite_phy(o_rsucs, swup0)
      CALL histwrite_phy(o_rsdcs, swdn0)
      CALL histwrite_phy(o_rlucs, lwup0)
      CALL histwrite_phy(o_rldcs, lwdn0)
IF(itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_t(1:klon,1:klev)+ &
      d_t_dyn(1:klon,1:klev)
ENDIF
      CALL histwrite_phy(o_tnt, zx_tmp_fi3d)
IF(itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=heat(1:klon,1:klev)/RDAY - &
      cool(1:klon,1:klev)/RDAY
ENDIF
      CALL histwrite_phy(o_tntr, zx_tmp_fi3d)
IF(itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)= (d_t_lsc(1:klon,1:klev)+ &
                                   d_t_eva(1:klon,1:klev)+ &
                                   d_t_vdf(1:klon,1:klev))/pdtphys
ENDIF
      CALL histwrite_phy(o_tntscpbl, zx_tmp_fi3d)
IF(itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_qx(1:klon,1:klev,ivap)+ &
      d_q_dyn(1:klon,1:klev)
ENDIF
      CALL histwrite_phy(o_tnhus, zx_tmp_fi3d)
IF(itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=d_q_lsc(1:klon,1:klev)/pdtphys+ &
                                 d_q_eva(1:klon,1:klev)/pdtphys
ENDIF
      CALL histwrite_phy(o_tnhusscpbl, zx_tmp_fi3d)
      CALL histwrite_phy(o_evu, coefm(:,:,is_ave))
IF(itap > 0) THEN
      zx_tmp_fi3d(1:klon,1:klev)=q_seri(1:klon,1:klev)+ &
                                 ql_seri(1:klon,1:klev) 
ENDIF
      CALL histwrite_phy(o_h2o, zx_tmp_fi3d)
       if (iflag_con >= 3) then
IF(itap > 0) THEN
             zx_tmp_fi3d(1:klon,1:klev)=-1 * (dnwd(1:klon,1:klev)+ &
                  dnwd0(1:klon,1:klev)) 
ENDIF
      CALL histwrite_phy(o_mcd, zx_tmp_fi3d)
IF(itap > 0) THEN
             zx_tmp_fi3d(1:klon,1:klev)=upwd(1:klon,1:klev) + &
                  dnwd(1:klon,1:klev)+ dnwd0(1:klon,1:klev) 
ENDIF
      CALL histwrite_phy(o_dmc, zx_tmp_fi3d)
       else if (iflag_con == 2) then
      CALL histwrite_phy(o_mcd,  pmfd)
      CALL histwrite_phy(o_dmc,  pmfu + pmfd)
       end if
      CALL histwrite_phy(o_ref_liq, ref_liq)
      CALL histwrite_phy(o_ref_ice, ref_ice)
      if (RCO2_per.NE.RCO2_act.OR.RCH4_per.NE.RCH4_act.OR. &
       RN2O_per.NE.RN2O_act.OR.RCFC11_per.NE.RCFC11_act.OR. &
       RCFC12_per.NE.RCFC12_act) THEN
IF(itap > 0) zx_tmp_fi2d(1 : klon) = swupp ( 1 : klon, klevp1 )
      CALL histwrite_phy(o_rsut4co2, zx_tmp_fi2d)
IF(itap > 0) zx_tmp_fi2d(1 : klon) = lwupp ( 1 : klon, klevp1 )
      CALL histwrite_phy(o_rlut4co2, zx_tmp_fi2d)
IF(itap > 0) zx_tmp_fi2d(1 : klon) = swup0p ( 1 : klon, klevp1 )
      CALL histwrite_phy(o_rsutcs4co2, zx_tmp_fi2d)
IF(itap > 0) zx_tmp_fi2d(1 : klon) = lwup0p ( 1 : klon, klevp1 )
      CALL histwrite_phy(o_rlutcs4co2, zx_tmp_fi2d)
      CALL histwrite_phy(o_rsu4co2, swupp)
      CALL histwrite_phy(o_rlu4co2, lwupp)
      CALL histwrite_phy(o_rsucs4co2, swup0p)
      CALL histwrite_phy(o_rlucs4co2, lwup0p)
      CALL histwrite_phy(o_rsd4co2, swdnp)
      CALL histwrite_phy(o_rld4co2, lwdnp)
      CALL histwrite_phy(o_rsdcs4co2, swdn0p)
      CALL histwrite_phy(o_rldcs4co2, lwdn0p)
      ENDIF
        IF (nqtot.GE.3) THEN
         DO iq=3,nqtot
             CALL histwrite_phy(o_trac(iq-2), qx(:,:,iq))
             CALL histwrite_phy(o_dtr_vdf(iq-2),d_tr_cl(:,:,iq-2))
             CALL histwrite_phy(o_dtr_the(iq-2),d_tr_th(:,:,iq-2))
             CALL histwrite_phy(o_dtr_con(iq-2),d_tr_cv(:,:,iq-2))
             CALL histwrite_phy(o_dtr_lessi_impa(iq-2),d_tr_lessi_impa(:,:,iq-2))
             CALL histwrite_phy(o_dtr_lessi_nucl(iq-2),d_tr_lessi_nucl(:,:,iq-2))
             CALL histwrite_phy(o_dtr_insc(iq-2),d_tr_insc(:,:,iq-2))
             CALL histwrite_phy(o_dtr_bcscav(iq-2),d_tr_bcscav(:,:,iq-2))
             CALL histwrite_phy(o_dtr_evapls(iq-2),d_tr_evapls(:,:,iq-2))
             CALL histwrite_phy(o_dtr_ls(iq-2),d_tr_ls(:,:,iq-2))
             CALL histwrite_phy(o_dtr_trsp(iq-2),d_tr_trsp(:,:,iq-2))
             CALL histwrite_phy(o_dtr_sscav(iq-2),d_tr_sscav(:,:,iq-2))
             CALL histwrite_phy(o_dtr_sat(iq-2),d_tr_sat(:,:,iq-2))
             CALL histwrite_phy(o_dtr_uscav(iq-2),d_tr_uscav(:,:,iq-2))
         zx_tmp_fi2d=0.
IF(itap > 0) THEN
         DO k=1,klev
            zx_tmp_fi2d(:)=zx_tmp_fi2d(:)+zmasse(:,k)*qx(:,k,iq)
         ENDDO
ENDIF
            CALL histwrite_phy(o_trac_cum(iq-2), zx_tmp_fi2d)
         ENDDO
        ENDIF


    IF(vars_defined) THEN
! On synchronise les fichiers pour IOIPSL
      DO iff=1,nfiles
          IF (ok_sync .AND. clef_files(iff)) THEN
!$OMP MASTER
              CALL histsync(nid_files(iff))
!$OMP END MASTER
          ENDIF
      END DO

    ELSE
    vars_defined = .TRUE.
    ENDIF

      


    END SUBROUTINE phys_output_write



  END MODULE phys_output_write_mod

